<?php
/**
 * ominis functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package ominis
 */

if ( ! function_exists( 'ominis_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function ominis_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on ominis, use a find and replace
		 * to change 'ominis' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'ominis', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'ominis' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'ominis_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
		
	}
endif;
add_action( 'after_setup_theme', 'ominis_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ominis_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'ominis_content_width', 640 );
}
add_action( 'after_setup_theme', 'ominis_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ominis_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'ominis' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'ominis' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer', 'ominis' ).' 1',
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'ominis' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer', 'ominis' ).' 2',
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'ominis' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer', 'ominis' ).' 3',
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'ominis' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'ominis_widgets_init' );

/**
 * Add Posts Formats.
 */
add_theme_support( 'post-formats', array( 'gallery' ) );
 
 /**
 * Enqueue scripts and styles.
 */
function ominis_scripts() {
	wp_enqueue_style( 'ominis-style', get_stylesheet_uri() );
	wp_enqueue_style( 'bootstrap-4-5', get_template_directory_uri() . '/assets/css/bootstrap.min.css',array(),null);
	wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css',array(),null);
	wp_enqueue_style( 'fontawesome_5', get_template_directory_uri() . '/assets/css/fontawesome.min.css',array(),null);
	
	wp_enqueue_style( 'ominis-custom-style', get_template_directory_uri() . '/ominis.css', array(), '1.0.7' );
	wp_enqueue_style( 'ominis-content-home', get_template_directory_uri() . '/layouts/content-home.css', array(), '1.0.2' );
	
	wp_enqueue_script( 'jquery_js', get_template_directory_uri() . '/assets/js/jquery.3.3.1.min.js', array(), null, true );
	wp_enqueue_script( 'bootstrap_js_4', get_template_directory_uri() . '/assets/js/bootstrap.bundle.min.js', array(), null, true );
	wp_enqueue_script( 'fancybox_js', get_template_directory_uri() . '/assets/js/jquery.fancybox.min.js', array(), null, true );
	wp_enqueue_script( 'isotope_js', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', array(), null, true );
	wp_enqueue_script( 'imagesloaded_js', get_template_directory_uri() . '/assets/js/imagesloaded.pkgd.min.js', array(), null, true );

	wp_enqueue_script( 'ominis-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'ominis-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	wp_enqueue_script( 'functions_js', get_template_directory_uri() . '/js/functions.js', array(), '1.7', true );
}
add_action( 'wp_enqueue_scripts', 'ominis_scripts' );

/**
 * Personalizamos el menu anadiendo la opcion de personalizar las clases a los <li>.
 */
function add_additional_class_on_li($classes, $item, $args) {
    if($args->add_li_class) {
        $classes[] = $args->add_li_class;
    }
    return $classes;
}
add_filter('nav_menu_css_class', 'add_additional_class_on_li', 1, 3);

/**
 * Personalizamos el menu anadiendo la opcion de personalizar las clases a los <a>.
 */
function add_additional_class_on_a($classes, $item, $args) {
    if($args->add_a_class) {
        $classes['class'] = $args->add_a_class;
    }
    return $classes;
}
add_filter('nav_menu_link_attributes', 'add_additional_class_on_a', 1, 3);

/**
 * Anadimos la class de BS "active" al enlace activo<a>.
 */
function special_nav_class($classes, $item){
     if( in_array('current-menu-item', $classes) ){
             $classes[] = 'active ';
     }
     return $classes;
}
add_filter('nav_menu_css_class' , 'special_nav_class' , 10 , 2);

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}


/**
 * Recupero las opciones personalizadas.
 */
$dataOminis = get_option('ominis_theme_options');


/**
 * Anado al menu las instrucciones del tema.
 */
add_action('admin_menu', 'ominis_menu');

/**
 * Config menu item
 */
function ominis_menu(){
	add_theme_page( 'Ominis Instrucciones', 'O Tema', 'manage_options', 'ominis-tema', 'ominis_instrucciones' );
}

/**
 * Contenido de las instrucciones.
 */
function ominis_instrucciones() {
?>
	<div class="wrap">
		<h2>Ominis Tema: Instrucciones <small>1.5.2</small></h2>
		<h3>Entradas</h3>
		<p>El tema Ominis est&aacute; optimizado para mostrar las &uacute;ltimas entradas en la p&aacute;gina de inicio. Para mostrarlas correctamente es necesario configurar para cada entrada:</p>
		<ol>
			<li>
				<p><strong>Imagen destacada</strong>: adjunta una imagen con un tama&ntilde;o de 400px de ancho por 500px de alto.</p>
			</li>
			<li>
				<p><strong>Extracto</strong>: a&ntilde;ade un peque&ntilde;o texto descriptivo.</p>
			</li>
		</ol>
		<p>Adem&aacute;s, para las entradas hay dos formatos disponibles:</p>
		<ol>
			<li>
				<p><strong>Est&aacute;ndar</strong>: formato por defecto.</p>
			</li>
			<li>
				<p><strong>Galer&iacute;a (optimizado para el nuevo editor Guternberg)</strong>: a&ntilde;ade cada imagen dentro de un bloque de "Imagen" para crear un mos&aacute;ico de im&aacute;genes.</p>
				<p>En el apartado de "Avanzado" de cada bloque, a&ntilde;ade clases CSS adicionales como si fueran etiquetas para crear un men&uacute; de filtros al principio de la galer&iacute;a.</p>
			</li>
		</ol>
		<h3>P&aacute;ginas</h3>
		<p>Para las p&aacute;ginas hay tres plantillas disponibles:</p>
		<ol>
			<li>
				<p><strong>Plantilla por defecto</strong>: formato por defecto.</p>
			</li>
			<li>
				<p><strong>Mos&aacute;ico (optimizado para el nuevo editor Guternberg)</strong>: a&ntilde;ade cada imagen dentro de un bloque de "Imagen" para crear un mos&aacute;ico de im&aacute;genes.</p>
			</li>
			<li>
				<p><strong>Mos&aacute;ico con filtros (optimizado para el nuevo editor Guternberg)</strong>: a&ntilde;ade cada imagen dentro de un bloque de "Imagen" para crear un mos&aacute;ico de im&aacute;genes.</p>
				<p>En el apartado de "Avanzado" de cada bloque, a&ntilde;ade clases CSS adicionales como si fueran etiquetas para crear un men&uacute; de filtros al principio de la galer&iacute;a.</p>
			</li>
		</ol>
		<h3>Redes sociales</h3>
		<p>En el men&uacute; <a href="<?php echo admin_url('customize.php?autofocus[section]=rrss');?>" target="_blank">Apariencia &gt; Personalizar: RRSS</a> se a&ntilde;aden los enlaces a las redes sociales que se quieren mostrar en el men&uacute; principal.</p>
		<h3>Cr&eacute;ditos</h3>
		<p>En el men&uacute; <a href="<?php echo admin_url('customize.php?autofocus[section]=footer');?>" target="_blank">Apariencia &gt; Personalizar: Pi&eacute; de p&aacute;gina</a> se cambia el texto que aparece en la zona de cr&eacute;ditos en el pi&eacute; de p&aacute;gina</p>
		<h3>Pol&iacute;tica de cookies</h3>
		<p>En el men&uacute; <a href="<?php echo admin_url('customize.php?autofocus[section]=footer');?>" target="_blank">Apariencia &gt; Personalizar: Pi&eacute; de p&aacute;gina</a> se selecciona la p&aacute;gina que contendr&aacute; la informaci&oacute;n de la pol&iacute;tica de cookies del sitio web.</p>
		<p>El texto de aviso se personaliza en el archivo de traduci&oacute;n.</p>
	</div>
<?php	
}